@@ -1,4 +1,4 @@
-/*  init.pl,v 1.24 1995/06/21 14:47:59 jan Exp
+/*  init.pl,v 1.25 1995/07/24 15:08:18 jan Exp
 
     Copyright (c) 1990 Jan Wielemaker. All rights reserved.
     jan@swi.psy.uva.nl
@@ -452,11 +452,11 @@ $chk_file(File, Exts, FullName) :-
 	$absolute_file_name(Extended, FullName).
 $chk_file(File, Exts, FullName) :-
 	source_location(ContextFile, _Line),
-	$file_dir_name(ContextFile, ContextDir), !,
+	$file_dir_name(ContextFile, ContextDir),
 	$concat_atom([ContextDir, /, File], AbsFile),
 	member(Ext, Exts),
 	ensure_extension(AbsFile, Ext, Extended),
-	exists_file(Extended),
+	exists_file(Extended), !,
 	$absolute_file_name(Extended, FullName).
 $chk_file(File, Exts, FullName) :-
 	member(Ext, Exts),
