@@ -1,4 +1,4 @@
-/*  pl-prims.c,v 1.24 1995/06/14 08:22:13 jan Exp
+/*  pl-prims.c,v 1.26 1995/07/26 14:12:10 jan Exp
 
     Copyright (c) 1990 Jan Wielemaker. All rights reserved.
     See ../LICENCE to find out about your rights.
@@ -526,6 +526,37 @@ pl_arg(register Word n, register Word term, register Word arg, word b)
 }
 	
 
+word
+pl_setarg(Word n, Word term, Word value)
+{ int argn;
+  Word a;
+
+  if ( !isTerm(*term) || !isInteger(*n) )
+    return warning("$setarg/3: instantiation fault");
+  
+  argn = (int) valNum(*n);
+  if ( argn < 1 || argn > functorTerm(*term)->arity )
+    fail;
+
+  a = argTermP(*term, argn-1);
+
+					/* this is unify(), but the */
+					/* assignment must *not* be trailed */
+  if ( isVar(*value) )
+  { if ( value < a )
+    { *a = makeRef(value);
+    } else if ( a < value )
+    { setVar(*a);
+      *value = makeRef(a);
+    } else
+      setVar(*a);
+  } else
+    *a = *value;
+
+  succeed;
+}
+
+
 /*  Determine the length of a list. If the list is not proper (or not
     a list at all) -1 is returned.
 
